library("tidyr")

# sucrose
pr<-read.table(file="pr.tab",header=F)
pr$schedule<-"zpr" # for sorting purpose
fr<-read.table(file="fr.tab",header=F)
fr$schedule<-"fr"
vr<-read.table(file="vr.tab",header=F)
vr$schedule<-"vr"
d0<-rbind(pr,vr,fr)

# water 

pr<-read.table(file="../water/water_pr.tab",header=F)
pr$schedule<-"zpr" # sorting
fr<-read.table(file="../water/water_fr.tab",header=F)
fr$schedule<-"fr"
vr<-read.table(file="../water/water_vr.tab",header=F)
vr$schedule<-"vr"
d1<-rbind(vr,fr, pr)

names(d0)<-c("cnt","rat","date","box","event","schedule")
names(d1)<-c("cnt","rat","date","box","event","schedule")
d0m<-aggregate(cnt~event+schedule, FUN=mean, data=d0)
d0s<-aggregate(cnt~event+schedule, FUN=function(x) sd(x)/sqrt(length(x)), data=d0)
d1m<-aggregate(cnt~event+schedule, FUN=mean, data=d1)
d1s<-aggregate(cnt~event+schedule, FUN=function(x) sd(x)/sqrt(length(x)), data=d1)

cbind(d0m,d0s)
cbind(d1m,d1s)
ti<-"../../figures/activities_mean.eps"
postscript(file=ti,width=10,height=5,onefile=F,horizontal=F,paper="special")  
# sucrose
d0mw<-spread(d0m, schedule, cnt)
d0sw<-spread(d0s, schedule, cnt)
y<-as.matrix(d0mw[,-1])
err<-as.matrix(d0sw[,-1])
#
par(mar=c(3,4,3,2))
par(mfcol=c(1,2))
x<-barplot( y , beside=T,log="y", ylim=c(1,10000), names.arg=c("FR10", "VR10", "PR"), main="Operant Licking for Sucrose", ylab="Counts" )
arrows(x, y, x, y + err, angle = 90, length = .02, code = 3)  
text(x[c(2,5,8)+0.3], y[c(2,5,8)]*2.55, c("***", "***", "**"), font=2, cex=1.4) 
#legend("topleft", bty="n", fill=c("grey30", "grey", "grey95"), c("Active Spout", "Inactive Spout", "Reward"))
# water
d1mw<-spread(d1m, schedule, cnt)
d1sw<-spread(d1s, schedule, cnt)
y<-as.matrix(d1mw[,-1])
err<-as.matrix(d1sw[,-1])
x<-barplot( y , beside=T,log="y", ylim=c(1,10000), names.arg=c("FR10", "VR10", "PR" ), main="Operant Licking for Water", ylab="Counts" )
arrows(x, y, x, y + err, angle = 90, length = .02, code = 3)  
text(x[c(2,5,8)+0.3], y[c(2,5,8)]*2.55, "*", font=2, cex=1.4) 
legend("topleft", bty="n", fill=c("grey30", "grey", "grey95"), c("Active Spout", "Inactive Spout", "Reward"))
dev.off()


# t test for sucrose
d2<-subset(d0, event!="REWARD")
d2vr<-subset(d2, schedule=="vr")
t.test(log(cnt)~event, paired=T, d2vr)
d2fr<-subset(d2, schedule=="fr")
t.test(log(cnt)~event, paired=T, d2fr)
d2pr<-subset(d2, schedule=="zpr")
t.test(log(cnt)~event, paired=T, d2pr)
# t test for water
d2<-subset(d1, event!="REWARD")
d2vr<-subset(d2, schedule=="vr")
t.test(log(cnt)~event, paired=T, d2vr)
d2fr<-subset(d2, schedule=="fr")
t.test(log(cnt)~event, paired=T, d2fr)
d2pr<-subset(d2, schedule=="zpr")
t.test(log(cnt)~event, paired=T, d2pr)

